The Chandler Wobble Challenge | GeoEnergy Math
Description: In the last post I mentioned I was trying to simplify the ENSO model. Right now the forcing is a mix of angular momentum variations related to Chandler wobble and lunisolar tidal pull. This is more…
Date: 2017-03-04T21:55:05+00:00

# The Chandler Wobble Challenge

March 4, 2017June 16, 2020 / Paul Pukite (@whut)

In the last post I mentioned I was trying to simplify the ENSO model. Right now the forcing is a mix of angular momentum variations related to Chandler wobble and lunisolar tidal pull. This is more complex than I would like to see, as there are a mix of potentially confounding factors. So what happens if the Chandler wobble is directly tied to the draconic/nodal cycles in the lunar tide? There is empirical evidence for this even though it is not outright acknowledged in the consensus geophysics literature. What you will find are many references to the long period nodal cycle of 18.6 years (example), which is clearly a lunar effect. If that is indeed the case, then the behavior of ENSO is purely lunisolar, as the Chandler wobble behavior is subsumed. That simplification would be significant in further behavioral modeling.

The figure below is my fit to the Chandler wobble, seemingly matching the aliased lunar draconic cycle rather precisely, taken from a previous blog post:

The consensus is that it is impossible for the moon to induce a nutation in the earth’s rotation to match the Chandler wobble. Yet, the seasonally reinforced draconic pull leads to an aliasing that is precisely the same value as the Chandler wobble period over the span of many years. Is this just coincidence or is there something that the geophysicists are missing?

It’s kind of hard to believe that this would be overlooked, and I have avoided discussing the correlation out of deference to the research literature. Yet the simplification to the ENSO model that a uniform lunisolar forcing would result in shouldn’t be dismissed. To quote Clinton: “What if it is the moon, stupid?”

In the current research literature, the Chandler wobble is described as an impulse response with a characteristic frequency determined by the earth’s ellipticity.

> https://en.wikipedia.org/wiki/Chandler_wobble “The existence of Earth’s free nutation was predicted by Isaac Newton in Corollaries 20 to 22 of Proposition 66, Book 1 of the Philosophiæ Naturalis Principia Mathematica, and by Leonhard Euler in 1765 as part of his studies of the dynamics of rotating bodies. Based on the known ellipticity of the Earth, Euler predicted that it would have a period of 305 days. Several astronomers searched for motions with this period, but none was found. Chandler’s contribution was to look for motions at any possible period; once the Chandler wobble was observed, the difference between its period and the one predicted by Euler was explained by Simon Newcomb as being caused by the non-rigidity of the Earth. The full explanation for the period also involves the fluid nature of the Earth’s core and oceans .. “

There is a factor known as the Q-value which describes the resonant “quality” of the impulse response, classically defined as the solution to a 2nd-order DiffEq. The higher the Q, the longer the oscillating response. The following figure shows the impulse and response for a fairly low Q-value. It’s thought that the Chandler wobble Q-value is very high, as it doesn’t seem to damp quickly.

In contrast, ocean tides are not described as a characteristic frequency but instead as a transfer function and a “steady-state” response due to the forcing frequency. The forcing frequency is in fact carried through from the input stimulus to the output response. In other words, the tidal frequency matches the rhythm of the lunar (and solar) orbital frequency. There may be a transient associated with the natural response but this eventually transitions into the steady-state through the ocean’s damping filter as shown below:

This behavior is well known in engineering and science circles and explains why the recorded music you listen to is not a resonant squeal but an amplified (and phase-delayed) replica of the input bits.

So why does the Chandler wobble appear close to 433 days instead of the 305 days that Euler predicted? If there was a resonance close to 305 days, any forcing frequency would be amplified in proportion to how close it was to 305 (or larger in Newcomb’s non-rigid earth model). Therefore, why can’t the aliased draconic lunar forcing cycle of 432.76 days be responsible for the widely accepted Chandler wobble of 433 days?

This is the biannual geometry giving the driving conditions, which I used in the QBO model.

And this is the strength of the draconic lunar pull at a sample of two times a year, computed according to the formula cos(2π/(13.6061/365.242)*t), where 13.6061 days is the lunar draconic fortnight or half the lunar draconic month.

We can count ~127 cycles in 150 years, which places it between 432 and 433 days, which is the Chandler wobble period.

Yet again Wikipedia explains it this way:

> “While it has to be maintained by changes in the mass distribution or angular momentum of the Earth’s outer core, atmosphere, oceans, or crust (from earthquakes), for a long time the actual source was unclear, since no available motions seemed to be coherent with what was driving the wobble. One promising theory for the source of the wobble was proposed in 2001 by Richard Gross at the Jet Propulsion Laboratory managed by the California Institute of Technology. He used angular momentum models of the atmosphere and the oceans in computer simulations to show that from 1985 to 1996, the Chandler wobble was excited by a combination of atmospheric and oceanic processes, with the dominant excitation mechanism being ocean‐bottom pressure fluctuations. Gross found that two-thirds of the “wobble” was caused by fluctuating pressure on the seabed, which, in turn, is caused by changes in the circulation of the oceans caused by variations in temperature, salinity, and wind. The remaining third is due to atmospheric fluctuations.”

Like ENSO and QBO, there is actually no truly accepted model for the Chandler wobble behavior. The one I give here appears just as valid as any of the others. One can’t definitely discount it because the lunar draconic period precisely matches the CW period. If it did’t match then the hypothesis could be roundly rejected.

And the same goes for the QBO and ENSO models described on these pages. The aliased lunisolar models match the data nicely in each of those cases as well and so can’t easily be rejected. That’s why I have been hammering at these models for so long, as a unified theory of lunisolar geophysical forcing is so tantalizingly close — one for the atmosphere (QBO), one for the ocean (ENSO), and one for the earth itself (Chandler wobble). These three will then unify with the generally accepted theory for ocean tides.

With that unification in mind, here is the math on the Chandler wobble. We start with the seasonally-modulated draconic lunar forcing. This has an envelope of a full-wave rectified signal as the moon and sun will show the greatest gravitational pull on the poles during the full northern and southern nodal excursions (i.e. the two solstices). This creates a full period of a 1/2 year.

The effective lunisolar pull is the multiplication of that envelope with the complete cycle draconic month of 2π/ω0 =27.2122 days. Because the full-wave rectified signal will create a large number of harmonics, the convolution in the frequency domain of the draconic period with the biannually modulated signal generates spikes at intervals of :

According to the Fourier series expansion in the figure above, the intensity of the terms will decrease left to right as 1/n^2, that is with decreasing frequency. The last term shown correlates to the Chandler wobble period of 1.185 years = 432.77 days.

One would think this decrease in intensity is quite rapid, but because of the resonance condition of the Chandler wobble nutation, a compensating amplification occurs. Here is the frequency response curve of a 2nd-order resonant DiffEq, written in terms of an equivalent electrical RLC circuit.

So, if we choose values for RLC to give a resonance close to 433 days and with a high enough Q-value (>100), then the diminishing amplitude of the Fourier series is amplified by the peak of the nutation response. Note that it doesn’t have to match exactly to the peak, but somewhere within the halfwidth, where Q = ω/Δω

So we see that the original fortnightly period of 13.606 days is retained, but what also emerges is the 13th harmonic of that signal located right at the Chandler wobble period.

That’s how a resonance works in the presence of a driving signal. It’s not the characteristic frequency that emerges, but the forcing harmonic closest to the resonance frequency. And that’s how we get the value of 432.77 days for the Chandler wobble. It may not be entirely intuitive but that’s the way that the math of the steady-state dynamics works out.

Alas, you won’t find this explanation anywhere in the research literature, even though the value of the Chandler wobble has been known since 1891 ! Like the recent finding that the moon is proving a significant gravitational forcing in triggering earthquakes, the same could be asserted for the moon’s direct influence on the Chandler wobble. Perhaps, it has taken this long because the data has become more abundant and more precise and it becomes harder to argue against the parsimonious correlation with a rather obvious and plausible physical explanation. For the Chandler wobble, nothing that complicated here at all, just a limited understanding on how seasonal physical aliasing can come about, and the admission that the forcing period carries through a resonance.

### Share this:

- Twitter
- Facebook

Like Loading...

### Related

## 18 thoughts on “The Chandler Wobble Challenge”

1. If I understand correctly, with your ENSO model you are talking about the thermocline sloshing being one of the mechanisms of temperature change at the ocean surface.

   I’m now wondering how much is the ocean fluid mass relocating with that same tidal pull, being deep ocean mass shifting of water from east to west and back. Would that mass movement be enough to either excite or stimulate the Chandler wobble?

   How close is that lunar tidal mass movement of water to any of the specific harmonics in question?

   Like Like

   Reply

   - Peter, I have strong evidence that ENSO dynamics is completely tidally driven. The Chandler wobble precisely aligns with the lunar draconic tide aliased with the seasonal forcing.

     Like Like

     Reply

     - OK, thanks. I understand that to mean that the lunar gravitational effects directly on the earth are the major cause, and any centre of mass changes in the earth as a result of the oceans tidal movements would effectively be a very low order factor.

       Like Like

2. Pingback: Tidal Model of ENSO | context/Earth

3. Hi, I’d like to ask you something. Basically I believe the excitement in the wobble is a cycle and it is at its unexcited state at the minute so an excitement in it is due.

   I agree the lunar pull on deep sea ocean mass causes the excitement. I want to put it to you that in order for that to happen the mass must increase. You would tell there was an increase in water mass by a few things, water pressure at depth would increase, salinity would drop (only extra water available is locked in ice as fresh water) air pressure would increase. But also you need to remove weight from the poles as the ice mass is a counter weight that actually reduces the wobble.

   Please look at the earth right now, the ice is almost gone so the counter weight is being removed. That water is in the ocean and is therefore increasing the water pressure (which would create more drag on the trenches). Now I want you to run your models again please, if possible. But this time move the polar ice caps water mass into the equatorial ocean mass again and see how much of a wobble you can get when the moon pulls all the extra mass around the world.

   There is a second cycle with the wobble that repeats every 100 years or ten of the enos cycles you mention (they seem ten years long).

   What happens is the ice increases to the size of it was in the 70’s which is then so large it counter acts the wobble and forces it to its centre rotation position (now and in the 1920’s) when it is in this position as the poles are getting more say and less night they warm and melt the water sending it down to the equator. This then causes all of the signs you see before an excitement in the wobble. It then excites which increases night length at the pole. Freezes the water, reducing water level, increasing salinity and so on until it gets to the size it was in the 70’s again roughly.

   One reason for this is the pattern in both the wobble, polar temps and ice cap size over the last 100 years fit together like jigsaw puzzle pieces but also flood data. The biggest floods always happen in the 1920-1940 period each century. You can literally match the melted ice cap with a major flood set (exactly like this year 2021)

   Would this at all be possible. We have had 100, 100 year floods all 50 years ahead of co2 predictions so co2 seems an unlikely cause for this years floods. “It caught us by surprise” is the phrase but it shouldn’t. We saw a low wobble so we should have known they were coming.

   Thanks

   Like Like

   Reply

4. The sun’s and the moon’s nodal cycle synchronize at the Chandler wobble cycle — no need to make it any more complicated at the moment because even this straightforward explanation is not accepted. Perhaps later some secondary aspects can be considered.

   Like Like

   Reply

   - Does that mean an eclipse

     Please look at the polar temperatures and the ice mass size at the time of the last excitement. There was no ice mass on the pole. All the extra mass was at the equator.

     Put it all together, massive amount of extra water increasing pressure at sea depth then the extra pull from that event on the earths mass plus all the extra water mass.

     Eclipses happen often but don’t excite the wobble. You say the simple explanation of the sun and moons nodes synchronising isn’t fully accepted. So don’t complicate it but if it’s not accepted because the combined gravitational pull was not enough then I believe the extra mass of the polar ice would produce the difference or at least definitely increase the effect of the gravitational pull of the synchronisation.

     Your saying in the comment above that enso is completely tidal driven. I just don’t think you have seen how much extra water was available in tides at the time. Also weight on the axis of spin would certainly affect wobble so removing the ice caps would also affect it.

     I believe these are two observations that are missing as they are most certainly true for the time of the last excitement. It looks to be in 1939 the last excitement. when polar average temperature was 2 degrees and the ice mass had been its lowest in record (it still isn’t this low now). So you would have also definitely seen desalination and increased sea pressure. Is there a desalination event before an excitement?

     Do you have an exact date it took the turn in the 30’s. Sorry.

     Could you please just for fun put the 1900’s wobble data graph above the 1900’s Greenland ice sheet mass data and see what I mean.

     Like Like

     Reply

     - No. The model that I propose is much more basic than the convoluted mess of an explanation than you are suggesting. I kind of doubt that you want to understand and that your mind is made up already. So it goes.

       > ” So don’t complicate it but if it’s not accepted because the combined gravitational pull was not enough”

       You do realize that the motion of the pole amounts to a movement of at most 15 meters every 6.5 years? The moon can pull a tide, so why not that amount, especially if it’s within the wobble’s resonant response envelope.

       Like Like

     - Iâll give it one last go.
       Iâm am concerned with the 180 degree turns only from then the wobble changes from a degrading inward spin and a expanding outward wobble.
       Basically I am looking at the earth as a hammer thrower spinning around. At the minute the polar ice caps are almost gone. These are his feet and head, the hammer is the tide and the body of the thrower is the earth.
       So as the hammer thrower is spinning around Imagine his head and feet disappear and the weight goes into the hammer. So now the hammer thrower is quite unbalanced but is still managing to hold his spin.
       Now as heâs spinning around with no head and feet counteracting the weight of the hammer a tiny extra little bit of weight is added to the hammer for a split second. Just for one or two degrees of his spin. Would that pull the hammer thrower off balance.
       Adding a tiny bit of weight normally when he still had his head and the hammer was lighter would do nothing. So I canât be the nodal synchronisation on its own.
       The tide moves around the earth never endingly as well which only causes slight increases in the wobble, I do not believe they are responsible for the 180 degree turn on their own. They couldnât be. They certainly could be responsible for amplifying the spin and taking it further out to the largest point we saw in the 90âs.
       If it was tide alone though Why would the wobble reduce and increase as it does. The tide never changes. Only two certain things in life are tides and taxes. There is a variable with the tide though which is the volume of water it contains therefore itâs mass.
       Mass change of a mobile liquid as it moves across the surface of a spinning body could have two main affects on a spinning body near 2 large gravitational forces.
       1, the mass of the liquid could create increased drag on the planets surface so the tide caused by the local gravitational source would increase in power. It would have higher pressure at depth and therefore more friction would be created between it and the sea bed. It would also move with greater inertia meaning more force when it meets a dry land mass.
       2, the mass of the liquid would be creating a greater pull between it and the gravity sources and could be pulled towards the gravitational sources if they aligned.
       Now, going back to the hammer thrower. What would happen if we started to deduct the weight of the hammer slowly and moved the weight back to the head and feet of the thrower. Would he gain stability and have a tighter spin.
       If you look at those graphs as I have said this effect happens. The weight moves into the hammer. Itâs in it now.

       Like Like

     - Why don’t you just do the math as I have done? The moon goes through a complete north to south cycle every 27.212 days and that’s enough to synchronize with the annual cycle and create the observed 433 day Chandler wobble cycle AND 6.5 year envelope. END OF STORY unless you want to try to debunk it. Good luck with that

       Like Like

     - No need to bring Newton into this conversation.

       Like Like

     - “No need to bring Newton into this conversation”

       Spoken like a non-physicist. Listen, obviously one can’t do a controlled experiment on the earth to verify my conjecture but one can do the equivalent with magnetic forcing. Take a spinning sphere with a magnetic dipole (north and south pole) and alternate drawing a magnet close to each pole in a periodic fashion. The spinning sphere will develop a wobble exactly equivalent to the Chandler wobble at the frequency of the forcing. This can easily be done as a controlled experiment and is useful given the close equivalence of the attractive forcing mechanisms. You lose!

       Like Like

     - I appreciate your last response. However, I disagree that I lost, as I have learned something.
       I will be looking into your posts about El Nino Southern Oscillation and the lunar cycles impact climate variability.

       Like Like

5. I have just a basic understanding of what is discussed here.
   So what I understand this to be about is predicting Chandler’s wobble, what I have read in the past is that mass distribution at the equator should have the most impact on the behavior of the wobble. For me I just read that as total mass distribution has an effect on the behavior of the wobble.
   Something I didn’t see mentioned was how long does it take for a mass variant to affect or cause a deviation from predicted movement? Does each mass redistribution event cause increased or decreased excitation, can there be multiple events during the observed cycle that will affect the predictability model?
   What brought me to this site was searching for a pattern that could be used to predict seasons. A relationship of Chandler’s Wobble and the position of the Earth during it’s orbit. Two things created this query, comparing wobble, surface temperature, and precipitation over time. Second was a headline Weather makes Earth wobble (https://www.nbcnews.com/id/wbna13559838).
   So I was looking for the opposite, Wobble makes the weather.

   > Moderator’s note:
   > I don’t know what it is with these commenters that they can’t seem to understand something so basic as what I am trying to explain. Would they have the same problem if I was trying to explain a father giving their child a periodic push to his child on a swing-set? Even though initially the push will not be in sync with the natural cycle of the swing’s pendulum, eventually the swing’s pendulum will match that of the father’s rhythm. I don’t have to tell you this, you can try it yourself. There is NOTHING different in what the moon is doing to the earth apart from the fact that (1) it is impacting the angular momentum wobble instead of a pendulum and (2) the sun’s annual torque is also interfering with the moon’s torque. The Chandler wobble is just this — it’s a FORCED response nota a NATURAL response, contrary to what everyone has been led to believe.

   Like Like

   Reply

   - Look at my moderator’s note above, but consider this clueless question by Gary Moore

     > “What brought me to this site was searching for a pattern that could be used to predict seasons. “

     You do realize that the earth’s seasons are caused by the earth’s orbit around the sun given that the earth is tilted on its rotational axis? I shouldn’t laugh because even some Harvard graduates aren’t able to explain this, watch the video

     https://youtu.be/yO9mk8xTzdc

     Like Like

     Reply

     - Guess I thought you were smarter than that, predict seasons does mean when they start or end. Means warm cold hot dry etc. Nice to see arrogance on display.

       > Moderator’;s note:
       > If you were to use proper English you would say “What brought me to this site was searching for a pattern that could be used to predict seasonal extremes or seasonal variability”, not seasons.

       > In that case, what you would want to look at are my posts on models of El Nino Southern Oscillation where I explain how the lunar cycles impact climate variability. Apparently my arrogance knows no bounds because I know what I’m talking about, while you seem to have trouble expressing your thoughts.

       Like Like

6. 2 of the commenters are the names of late great British blues guitarists.

   Like Like

   Reply

   - The third man (Jon Welborn) to join the conversation is also a guitarist
     https://www.arkansasonline.com/news/2019/jul/31/man-32-sentenced-in-children-s-deaths-2/

     > “Welborn, who was irritated because Hairston wanted to stay at the residence and play pool, told her he was going to take the children home and then return for her, the news release stated. He then quickly backed the truck out of the driveway, down an embankment and into a pond, where it submerged, according to testimony.

     > The Paron man testified that he threw his daughter out of the truck’s window as it sank under the water and was unable to unbuckle his son’s car seat, watching as the 5-month-old’s head sank below the pond’s surface, according to the news release.

     > The prosecutor’s office said that, after escaping through the window of the truck, Welborn went back up the hill, entered the house and sat in a chair playing guitar.”

     The legend of Robert Johnson at the Crossroads was true 😑

     Like Like

     Reply

### Leave a comment Cancel reply

Δ

Search for:

# Tags

#shareEGU20 AI AMO AO Bloch wave Book Category Theory Chandler wobble ChatGPT Climate climate change climate modeling co2 common-mode compartmental model context cross-validation Darwin dipole DOF EGU EMI en Energy ENSO entropy Floquet Floquet Theory GEM Geoenergy GPT hovmoller IOD ITCZ Lakes Lindzen LOD LTE lunar Mathematica MaxEnt maximum entropy principle MJO ML MZM NAM NAO NINO4 NN nonlinear oil Oil Depletion oil shock model PDO Peak Oil PNA population QBO reliability research SAM SAO scalogram ScienceScoop Shock Model SOI SSW Takens tidal Tides TIW Tropical Instability Waves wavelets waves wind

# Recent Comments

| QBO Metrics | GeoEne… on Lunar Torque Controls All
| QBO Metrics | GeoEne… on Are the QBO disruptions a…
| QBO Metrics | GeoEne… on Dynamic Time Warping
| Jim on Nonlinear long-period tidal fo…
| 20yrs of blogging in… on Lunar Torque Controls All

# Recent Posts

- Bluesky
- QBO Metrics
- Low Dimensions
- 20yrs of blogging in hindsight
- Lunar Torque Controls All

# Top Posts & Pages

- Lunar Torque Controls All
- Mathematical GeoEnergy, update
- Mf vs Mm
- Wobble Perturbation
- Bluesky
- Variational Principles in Thermodynamics
- Nonlinear long-period tidal forcing with application to ENSO, QBO, and Chandler wobble
- The Chandler Wobble Challenge
- Millennium Prize Problem: Navier-Stokes
- Expansion of atmosphere and ocean

# GeoEnergy Math

- RSS - Posts
- RSS - Comments

# Posts —– ContextEarth.com=<2018, TheOilConundrum=<2014

- December 2024
- November 2024
- September 2024
- July 2024
- June 2024
- April 2024
- March 2024
- February 2024
- December 2023
- November 2023
- October 2023
- September 2023
- July 2023
- June 2023
- May 2023
- April 2023
- March 2023
- January 2023
- October 2022
- September 2022
- August 2022
- July 2022
- June 2022
- May 2022
- April 2022
- March 2022
- February 2022
- January 2022
- December 2021
- September 2021
- August 2021
- July 2021
- June 2021
- May 2021
- April 2021
- March 2021
- February 2021
- January 2021
- December 2020
- November 2020
- October 2020
- September 2020
- August 2020
- July 2020
- June 2020
- May 2020
- April 2020
- March 2020
- February 2020
- January 2020
- October 2019
- September 2019
- August 2019
- July 2019
- June 2019
- May 2019
- April 2019
- March 2019
- February 2019
- November 2018
- October 2018
- September 2018
- August 2018
- June 2018
- May 2018
- April 2018
- February 2018
- January 2018
- December 2017
- November 2017
- October 2017
- September 2017
- August 2017
- July 2017
- June 2017
- May 2017
- April 2017
- March 2017
- December 2016
- November 2016
- October 2016
- September 2016
- August 2016
- July 2016
- June 2016
- May 2016
- April 2016
- March 2016
- February 2016
- January 2016
- December 2015
- November 2015
- October 2015
- September 2015
- August 2015
- July 2015
- May 2015
- April 2015
- February 2015
- January 2015
- December 2014
- November 2014
- October 2014
- September 2014
- August 2014
- July 2014
- June 2014
- May 2014
- April 2014
- March 2014
- February 2014
- January 2014
- December 2013
- November 2013
- October 2013
- September 2013
- August 2013
- July 2013
- June 2013
- May 2013
- April 2013
- March 2013
- February 2013
- January 2013
- September 2012
- July 2012
- May 2012
- March 2012
- February 2012
- January 2012
- December 2011
- November 2011
- October 2011
- September 2011
- July 2011

# A badge of honor

- Comment
- Reblog
- Subscribe
  Subscribed
  - GeoEnergy Math
  Join 26 other subscribers
  - Already have a WordPress.com account? Log in now.
- - GeoEnergy Math
  - Subscribe
    Subscribed
  - Sign up
  - Log in
  - Copy shortlink
  - Report this content
  - View post in Reader
  - Manage subscriptions
  - Collapse this bar

%d